@@ -7,7 +7,7 @@ use Carp;
 use Moo;
 use namespace::clean;
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 my @languages   = qw( eo io pl );
 my %is_language = map { $_ => 1 } @languages;
@@ -71,7 +71,7 @@ Lingua::Stem::Patch - Patch stemmers for Esperanto and Ido
 
 =head1 VERSION
 
-This document describes Lingua::Stem::Patch v0.05.
+This document describes Lingua::Stem::Patch v0.06.
 
 =head1 SYNOPSIS
 
@@ -90,7 +90,8 @@ This document describes Lingua::Stem::Patch v0.05.
 
 This module contains a collection of stemmers for multiple languages using the
 Patch stemming algorithms. The languages currently implemented are
-L<Esperanto|Lingua::Stem::Patch::EO> and L<Ido|Lingua::Stem::Patch::IO>.
+L<Esperanto|Lingua::Stem::Patch::EO>, L<Ido|Lingua::Stem::Patch::IO>, and
+L<Polish|Lingua::Stem::Patch::PL>.
 
 This is a new project under active development and the current stemming
 algorithms are likely to change.
@@ -174,7 +175,7 @@ Nick Patch <patch@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-© 2014 Nick Patch
+© 2014–2015 Nick Patch
 
 This library is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
