@@ -6,7 +6,7 @@ use strict;
 use warnings;
 use parent 'Exporter';
 
-our $VERSION   = '0.05';
+our $VERSION   = '0.06';
 our @EXPORT_OK = qw( stem stem_io stem_aggressive stem_io_aggressive );
 
 *stem_io            = \&stem;
@@ -73,7 +73,7 @@ Lingua::Stem::IO - Ido stemmer
 
 =head1 VERSION
 
-This document describes Lingua::Stem::Patch::IO v0.05.
+This document describes Lingua::Stem::Patch::IO v0.06.
 
 =head1 SYNOPSIS
 
@@ -111,7 +111,7 @@ Nick Patch <patch@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-© 2014 Nick Patch
+© 2014–2015 Nick Patch
 
 This library is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
