@@ -6,7 +6,7 @@ use strict;
 use warnings;
 use parent 'Exporter';
 
-our $VERSION   = '0.05';
+our $VERSION   = '0.06';
 our @EXPORT_OK = qw( stem stem_pl );
 
 *stem_pl = \&stem;
@@ -178,7 +178,7 @@ Lingua::Stem::Patch::PL - Polish stemmer
 
 =head1 VERSION
 
-This document describes Lingua::Stem::Patch::PL v0.05.
+This document describes Lingua::Stem::Patch::PL v0.06.
 
 =head1 SYNOPSIS
 
@@ -220,7 +220,7 @@ L<code.shutterstock.com|http://code.shutterstock.com/>.
 
 =head1 COPYRIGHT AND LICENSE
 
-© 2014 Shutterstock, Inc.
+© 2014–2015 Shutterstock, Inc.
 
 This library is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
